@@ -32,15 +32,12 @@ describe 'ec2api::db::postgresql' do
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
-          :processorcount => 8,
-          :concat_basedir => '/var/lib/puppet/concat'
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
         }))
       end
-
-      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
-      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
-        it_behaves_like 'ec2api::db::postgresql'
-      end
+      it_behaves_like 'ec2api::db::postgresql'
     end
   end
 
